@@ -154,8 +154,7 @@ struct MiniaFunctor  {  void operator ()  (Parameter parameter)
     // link contigs
     uint nb_threads = 1;  // doesn't matter because for now link_tigs is single-threaded
     bool verbose = true;
-    link_tigs<span>(output, minia.k, nb_threads, minia.nbContigs, verbose);
-
+    link_tigs<span>(output, minia.k, nb_threads, minia.nbContigs, verbose, false);
 
     /** We gather some statistics. */
     minia.getInfo()->add (1, minia.getTimeInfo().getProperties("time"));
@@ -251,7 +250,7 @@ string Minia::assemble (/*const, removed because Simplifications isn't const any
     if (simplifyGraph)
     {
         int nbCores = getInput()->getInt(STR_NB_CORES);
-        bool verbose=true;
+        bool verbose=false;
         Simplifications<Graph_type,Node,Edge> graphSimplifications(&graph, nbCores, verbose);
 
         if (getParser()->saw("-no-tip-removal"))
@@ -274,8 +273,8 @@ string Minia::assemble (/*const, removed because Simplifications isn't const any
 			graphSimplifications._bulgeLen_kAdd = getInput()->getDouble("-bulge-len-kadd");
 		if (getParser()->saw("-bulge-altpath-kadd"))
 			graphSimplifications._bulgeAltPath_kAdd = getInput()->getDouble("-bulge-altpath-kadd");
-		if (getParser()->saw("-bulge-altpath-covMult"))
-			graphSimplifications._bulgeAltPath_covMult = getInput()->getDouble("-bulge-altpath-covMult");
+		if (getParser()->saw("-bulge-altpath-covmult"))
+			graphSimplifications._bulgeAltPath_covMult = getInput()->getDouble("-bulge-altpath-covmult");
 
 		if (getParser()->saw("-ec-len-kmult"))
 			graphSimplifications._ecLen_kMult = getInput()->getDouble("-ec-len-kmult");
@@ -310,6 +309,7 @@ string Minia::assemble (/*const, removed because Simplifications isn't const any
     /** We gather some statistics. */
     getInfo()->add (1, "stats");
     getInfo()->add (2, "traversal",         "%s", getInput()->getStr(STR_TRAVERSAL_KIND).c_str());
+    getInfo()->add (2, "nb_solid_kmers",         "%d", graph._nbSolidKmers);
     getInfo()->add (2, "nb_contigs",         "%d", nbContigs);
     getInfo()->add (2, "nb_small_contigs_discarded","%d", nbSmallContigs);
     getInfo()->add (2, "nt_assembled",      "%ld", totalNt);
